# frozen_string_literal: true

require 'influxdb-client'

module Latias
  # Influxdb
  module Influxdb
    # Bucket
    class Bucket
      attr_reader :url, :token, :bucket, :org, :use_ssl, :verify_mode, :precision

      def initialize
        set_default
      end

      def call
        all_query = "from(bucket: \"#{@bucket}\") #{@query}"
        @query = ''
        @client.create_query_api.query(query: all_query, org: @org)
      end

      def yield(query)
        @query += "#{new_command} yield(#{query})"
        self
      end

      def range(query)
        @query += "#{new_command} range(#{query})"
        self
      end

      def filter(query)
        @query += "#{new_command} filter(#{query})"
        self
      end

      def real_query(query)
        @query += query
      end

      private

      def set_default
        @query = ''
        @url = 'http://localhost:8086'
        @token = 'token'
        @bucket = 'bucket'
        @org = 'org'
        @use_ssl = false
        @verify_mode = OpenSSL::SSL::VERIFY_NONE
      end

      def new_command
        '|> '
      end

      def client_connection
        @client = InfluxDB2::Client.new(@url, @token,
                                        use_ssl: @use_ssl,
                                        verify_mode: @verify_mode.present? ? @verify_mode : OpenSSL::SSL::VERIFY_NONE,
                                        precision: InfluxDB2::WritePrecision::NANOSECOND)
      end
    end
  end
end
